        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 17 <strong>control</strong><br>0,3,9,14,15,20,24,28,29,30,33,39,41,45,46,48,49';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 14 <br>2,5,8,11,17,18,21,22,23,36,37,38,40,47';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>34</strong> miembros: 13 <br>4,6,7,16,19,25,26,27,32,34,35,44,50';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260721 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 7 <br>1,10,12,13,31,42,43';}
}
